http_digest_fields/content_digest

Values

pub fn create_digest_header_value(
  value: String,
  algorithm: String,
) -> Result(String, errors.DigestError)

Creates a Content-Digest header value for the given value and algorithm.

The value is expected to be a string representation of the content, and the algorithm should be a supported hash algorithm (e.g., “sha-256”, “sha-512”).

Search Document