http_digest_fields/errors
Types
Errors that can occur while creating a digest header value.
pub type DigestError {
AlgorithmError(String)
}
Constructors
-
AlgorithmError(String)Unsupported algorithm is provided
Errors that can occur while creating a digest header value.
pub type DigestError {
AlgorithmError(String)
}
AlgorithmError(String)
Unsupported algorithm is provided